Implements: Pythonic Interfaces
===============================

.. only:: html

    :Release: |version|
    :Date: |today|

.. toctree::
   :maxdepth: 2

   overview


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

